@@ -21,18 +21,15 @@ my $pass=shift or die;
 my $dba=DBIx::Array->new;
 $dba->connect($connect, $user, $pass, {AutoCommit=>1, RaiseError=>1});
 
-my $sql=q{SELECT LEVEL AS "Number",
-                 TRIM(TO_CHAR(LEVEL, 'rn')) as "Roman Numeral"
-            FROM DUAL
-      CONNECT BY LEVEL <= ?
-        ORDER BY LEVEL};
-my @data=$dba->sqlarrayarrayname($sql, 15); #[[Number=>"Roman Numeral"],
-                                            # [1=>"i"], [2=>"ii"], ...]
-
-print tablename(@data), "\n";
-
+print &tablename($dba->sqlarrayarrayname(&sql, 15)), "\n";
+  
 sub tablename {
   use CGI; my $html=CGI->new(""); #you would pass this reference
   return $html->table($html->Tr([map {$html->td($_)} @_]));
 } 
-
+  
+sub sql { #Oracle SQL
+  return q{SELECT LEVEL AS "Number",
+                  TRIM(TO_CHAR(LEVEL, 'rn')) as "Roman Numeral"
+             FROM DUAL CONNECT BY LEVEL <= ? ORDER BY LEVEL};
+}
